@@ -68,7 +68,7 @@ MainWindow::~MainWindow()
     QString tmpLog = "/tmp/" + QApplication::applicationName() + ".log";
     if (Cmd().getCmdOut("wc -l " + tmpLog + "| cut -f1 -d' '", true).toInt() > 7) { // only if log is large enough
         QString log = "/var/log/" + QApplication::applicationName() + ".log";
-        shell->runAsRoot("mv --backup=numbered " + log + " " + log + ".old; cp " + tmpLog + " " + log, nullptr, nullptr,
+        shell->runAsRoot("mv --backup=numbered " + log + ' ' + log + ".old; cp " + tmpLog + ' ' + log, nullptr, nullptr,
                          true);
     }
     delete ui;
@@ -91,7 +91,7 @@ void MainWindow::refresh()
     ui->rootLabel->hide();
     ui->rootCombo->hide();
     ui->buttonApply->setText(tr("Apply"));
-    ui->buttonApply->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok")));
+    ui->buttonApply->setIcon(QIcon::fromTheme("dialog-ok"));
     ui->buttonApply->setEnabled(true);
     ui->buttonCancel->setEnabled(true);
     ui->rootCombo->setDisabled(false);
@@ -105,9 +105,9 @@ void MainWindow::installGRUB()
     ui->buttonApply->setEnabled(false);
     ui->stackedWidget->setCurrentWidget(ui->outputPage);
 
-    const QString location = ui->locationCombo->currentText().section(QStringLiteral(" "), 0, 0);
+    const QString location = ui->locationCombo->currentText().section(' ', 0, 0);
     const QString text = tr("GRUB is being installed on %1 device.").arg(location);
-    QString root = "/dev/" + ui->rootCombo->currentText().section(QStringLiteral(" "), 0, 0);
+    QString root = "/dev/" + ui->rootCombo->currentText().section(' ', 0, 0);
 
     const QString &luks = luksMapper(root);
 
@@ -130,15 +130,14 @@ void MainWindow::installGRUB()
     // for grub-install access UEFI NVRAM entries
     if (ui->grubEspButton->isChecked()) {
         // ... mount efivarfs if not already mounted
-        shell->runAsRoot(QStringLiteral(
-            "grep -sq ^efivarfs /proc/self/mounts || "
-            "{ test -d /sys/firmware/efi/efivars && mount -t efivarfs efivarfs /sys/firmware/efi/efivars; }"));
-        // ...  remove dump-entries if exist to avoid "No space left on device" error
         shell->runAsRoot(
-            QStringLiteral("ls -1 /sys/firmware/efi/efivars | grep -sq ^dump && rm /sys/firmware/efi/efivars/dump*"));
+            "grep -sq ^efivarfs /proc/self/mounts || "
+            "{ test -d /sys/firmware/efi/efivars && mount -t efivarfs efivarfs /sys/firmware/efi/efivars; }");
+        // ...  remove dump-entries if exist to avoid "No space left on device" error
+        shell->runAsRoot("ls -1 /sys/firmware/efi/efivars | grep -sq ^dump && rm /sys/firmware/efi/efivars/dump*");
     }
     if (mountChrootEnv(root)) {
-        if (!checkAndMountPart(tmpdir.path(), QStringLiteral("/boot"))) {
+        if (!checkAndMountPart(tmpdir.path(), "/boot")) {
             cleanupMountPoints(tmpdir.path(), luks);
             refresh();
             return;
@@ -164,14 +163,14 @@ void MainWindow::installGRUB(const QString &location, const QString &path, const
         = QStringLiteral("chroot %1 grub-install --target=i386-pc --recheck --force /dev/%2").arg(path, location);
     if (ui->grubEspButton->isChecked()) {
         shell->runAsRoot("test -d " + path + "/boot/efi || mkdir " + path + "/boot/efi");
-        if (!checkAndMountPart(path, QStringLiteral("/boot/efi"))) {
+        if (!checkAndMountPart(path, "/boot/efi")) {
             cleanupMountPoints(path, luks);
             refresh();
             return;
         }
-        QString arch = shell->getCmdOut(QStringLiteral("arch"));
+        QString arch = shell->getCmdOut("arch");
         if (arch == "i686") { // rename arch to match grub-install target
-            arch = QStringLiteral("i386");
+            arch = "i386";
         }
         QString release
             = shell->getCmdOut(QStringLiteral("grep -oP '(?<=DISTRIB_RELEASE=).*' /etc/lsb-release")).left(2);
@@ -192,11 +191,11 @@ void MainWindow::repairGRUB()
     ui->buttonCancel->setEnabled(false);
     ui->buttonApply->setEnabled(false);
     ui->stackedWidget->setCurrentWidget(ui->outputPage);
-    QString part = "/dev/" + ui->locationCombo->currentText().section(QStringLiteral(" "), 0, 0);
+    QString part = "/dev/" + ui->locationCombo->currentText().section(' ', 0, 0);
 
     if (isMountedTo(part, "/")) { // on current root
         displayOutput();
-        bool ok = shell->runAsRoot(QStringLiteral("update-grub"));
+        bool ok = shell->runAsRoot("update-grub");
         disableOutput();
         displayResult(ok);
         refresh();
@@ -214,13 +213,12 @@ void MainWindow::repairGRUB()
 
     ui->outputLabel->setText(tr("The GRUB configuration file (grub.cfg) is being rebuilt."));
     if (mountChrootEnv(part)) {
-        if (!checkAndMountPart(tmpdir.path(), QStringLiteral("/boot"))) {
+        if (!checkAndMountPart(tmpdir.path(), "/boot")) {
             cleanupMountPoints(tmpdir.path(), luks);
             refresh();
             return;
         }
-        if (QFile::exists(tmpdir.path() + "/boot/efi")
-            && !checkAndMountPart(tmpdir.path(), QStringLiteral("/boot/efi"))) {
+        if (QFile::exists(tmpdir.path() + "/boot/efi") && !checkAndMountPart(tmpdir.path(), "/boot/efi")) {
             cleanupMountPoints(tmpdir.path(), luks);
             refresh();
             return;
@@ -249,7 +247,7 @@ void MainWindow::backupBR(const QString &filename)
     ui->buttonCancel->setEnabled(false);
     ui->buttonApply->setEnabled(false);
     ui->stackedWidget->setCurrentWidget(ui->outputPage);
-    const QString location = ui->locationCombo->currentText().section(QStringLiteral(" "), 0, 0);
+    const QString location = ui->locationCombo->currentText().section(' ', 0, 0);
     const QString text = tr("Backing up MBR or PBR from %1 device.").arg(location);
     ui->outputLabel->setText(text);
     const QString cmd = "dd if=/dev/" + location + " of=" + filename + " bs=446 count=1";
@@ -260,7 +258,7 @@ void MainWindow::backupBR(const QString &filename)
 // umount and clean temp folder
 void MainWindow::cleanupMountPoints(const QString &path, const QString &luks)
 {
-    if (path == QLatin1String("/")) {
+    if (path == "/") {
         return;
     }
     shell->runAsRoot("mountpoint -q " + path + "/boot/efi && umount " + path + "/boot/efi");
@@ -283,7 +281,7 @@ void MainWindow::guessPartition()
         for (int index = 0; index < ui->locationCombo->count(); index++) {
             QString drive = ui->locationCombo->itemText(index);
             if (shell->runAsRoot(
-                    "lsblk -ln -o PARTTYPE /dev/" + drive.section(QStringLiteral(" "), 0, 0)
+                    "lsblk -ln -o PARTTYPE /dev/" + drive.section(' ', 0, 0)
                     + "| grep -qEi "
                       "'0x83|0fc63daf-8483-4772-8e79-3d69d8477de4|44479540-F297-41B2-9AF7-D131D5F0458A|4F68BCE3-"
                       "E8CD-4DB1-96E7-FBCAF984B709'")) {
@@ -295,8 +293,7 @@ void MainWindow::guessPartition()
     // find first a partition with rootMX* label
     for (int index = 0; index < ui->rootCombo->count(); index++) {
         QString part = ui->rootCombo->itemText(index);
-        if (shell->runAsRoot("lsblk -ln -o LABEL /dev/" + part.section(QStringLiteral(" "), 0, 0)
-                             + "| grep -q rootMX")) {
+        if (shell->runAsRoot("lsblk -ln -o LABEL /dev/" + part.section(' ', 0, 0) + "| grep -q rootMX")) {
             ui->rootCombo->setCurrentIndex(index);
             // select the same location by default for GRUB and /boot
             if (ui->grubRootButton->isChecked()) {
@@ -309,7 +306,7 @@ void MainWindow::guessPartition()
     for (int index = 0; index < ui->rootCombo->count(); index++) {
         QString part = ui->rootCombo->itemText(index);
         if (shell->runAsRoot(
-                "lsblk -ln -o PARTTYPE /dev/" + part.section(QStringLiteral(" "), 0, 0)
+                "lsblk -ln -o PARTTYPE /dev/" + part.section(' ', 0, 0)
                 + "| grep -qEi "
                   "'0x83|0fc63daf-8483-4772-8e79-3d69d8477de4|44479540-F297-41B2-9AF7-D131D5F0458A|4F68BCE3-"
                   "E8CD-4DB1-96E7-FBCAF984B709'")) {
@@ -329,7 +326,7 @@ void MainWindow::restoreBR(const QString &filename)
     ui->buttonCancel->setEnabled(false);
     ui->buttonApply->setEnabled(false);
     ui->stackedWidget->setCurrentWidget(ui->outputPage);
-    const QString location = ui->locationCombo->currentText().section(QStringLiteral(" "), 0, 0);
+    const QString location = ui->locationCombo->currentText().section(' ', 0, 0);
     const auto ans = QMessageBox::warning(this, tr("Warning"),
                                           tr("You are going to write the content of ") + filename + tr(" to ")
                                               + location + tr("\n\nAre you sure?"),
@@ -351,7 +348,7 @@ void MainWindow::setEspDefaults()
     // remove non-ESP partitions
     for (int index = 0; index < ui->locationCombo->count(); index++) {
         const QString part = ui->locationCombo->itemText(index);
-        if (!shell->runAsRoot("lsblk -ln -o PARTTYPE /dev/" + part.section(QStringLiteral(" "), 0, 0)
+        if (!shell->runAsRoot("lsblk -ln -o PARTTYPE /dev/" + part.section(' ', 0, 0)
                               + "| grep -qiE 'c12a7328-f81f-11d2-ba4b-00a0c93ec93b|0xef'")) {
             ui->locationCombo->removeItem(index);
             index--;
@@ -434,7 +431,7 @@ void MainWindow::procDone()
     ui->buttonCancel->setEnabled(true);
     ui->buttonApply->setEnabled(true);
     ui->buttonApply->setText(tr("Back"));
-    ui->buttonApply->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
+    ui->buttonApply->setIcon(QIcon::fromTheme("go-previous"));
 }
 
 void MainWindow::displayOutput()
@@ -504,11 +501,11 @@ bool MainWindow::openLuks(const QString &part, const QString &mapper)
 void MainWindow::addDevToList()
 {
     QString cmd("lsblk -ln -o NAME,SIZE,LABEL,MODEL -d -e 2,11 -x NAME | grep -E '^x?[h,s,v].[a-z]|^mmcblk|^nvme'");
-    ListDisk = shell->getCmdOut(cmd).split(QStringLiteral("\n"), SKIPEMPTYPARTS);
+    ListDisk = shell->getCmdOut(cmd).split('\n', SKIPEMPTYPARTS);
 
-    cmd = QStringLiteral("lsblk -ln -o NAME,SIZE,FSTYPE,MOUNTPOINT,LABEL -e 2,11 -x NAME | "
-                         "grep -E '^x?[h,s,v].[a-z][0-9]|^mmcblk[0-9]+p|^nvme[0-9]+n[0-9]+p'");
-    ListPart = shell->getCmdOut(cmd).split(QStringLiteral("\n"), SKIPEMPTYPARTS);
+    cmd = "lsblk -ln -o NAME,SIZE,FSTYPE,MOUNTPOINT,LABEL -e 2,11 -x NAME | grep -E "
+          "'^x?[h,s,v].[a-z][0-9]|^mmcblk[0-9]+p|^nvme[0-9]+n[0-9]+p'";
+    ListPart = shell->getCmdOut(cmd).split('\n', SKIPEMPTYPARTS);
     ui->rootCombo->clear();
     ui->rootCombo->addItems(ListPart);
 
@@ -545,7 +542,7 @@ void MainWindow::targetSelection()
 
 void MainWindow::outputAvailable(const QString &output)
 {
-    //    if (output.contains("\r")) {
+    //    if (output.contains('\r')) {
     //        ui->outputBox->moveCursor(QTextCursor::Up, QTextCursor::KeepAnchor);
     //        ui->outputBox->moveCursor(QTextCursor::EndOfLine, QTextCursor::KeepAnchor);
     //    }
@@ -584,15 +581,15 @@ void MainWindow::buttonApply_clicked()
         } else if (ui->bakRadioButton->isChecked()) {
             ui->stackedWidget->setCurrentWidget(ui->selectionPage);
             ui->bootMethodGroup->setTitle(tr("Select Item to Back Up"));
-            ui->grubInsLabel->setText(QLatin1String(""));
-            ui->grubRootButton->setText(QStringLiteral("PBR"));
+            ui->grubInsLabel->clear();
+            ui->grubRootButton->setText("PBR");
             ui->grubEspButton->hide();
             // Restore backup button selected
         } else if (ui->restoreBakRadioButton->isChecked()) {
             ui->stackedWidget->setCurrentWidget(ui->selectionPage);
             ui->bootMethodGroup->setTitle(tr("Select Item to Restore"));
-            ui->grubInsLabel->setText(QLatin1String(""));
-            ui->grubRootButton->setText(QStringLiteral("PBR"));
+            ui->grubInsLabel->clear();
+            ui->grubRootButton->setText("PBR");
             ui->grubEspButton->hide();
         }
 
@@ -648,8 +645,7 @@ void MainWindow::buttonAbout_clicked()
             + tr("Simple boot repair program for MX Linux")
             + R"(</h3></p><p align="center"><a href="http://mxlinux.org">http://mxlinux.org</a><br /></p><p align="center">)"
             + tr("Copyright (c) MX Linux") + "<br /><br /></p>",
-        QStringLiteral("/usr/share/doc/mx-bootrepair/license.html"),
-        tr("%1 License").arg(QApplication::applicationDisplayName()));
+        "/usr/share/doc/mx-bootrepair/license.html", tr("%1 License").arg(QApplication::applicationDisplayName()));
     this->show();
 }
 
@@ -660,7 +656,7 @@ void MainWindow::buttonHelp_clicked()
 
     QString url("/usr/share/doc/mx-bootrepair/mx-boot-repair.html");
     if (lang.startsWith(QLatin1String("fr"))) {
-        url = QStringLiteral("https://mxlinux.org/wiki/help-files/help-r%C3%A9paration-d%E2%80%99amor%C3%A7age");
+        url = "https://mxlinux.org/wiki/help-files/help-r%C3%A9paration-d%E2%80%99amor%C3%A7age";
     }
     displayDoc(url, tr("%1 Help").arg(this->windowTitle()));
 }
@@ -678,7 +674,7 @@ bool MainWindow::checkAndMountPart(const QString &path, const QString &mountpoin
 {
     if (!shell->runAsRoot("test -n \"$(ls -A " + path + mountpoint + ")\"")) {
         const QString part = selectPart(path, mountpoint);
-        if (!shell->runAsRoot("mount " + part + " " + path + mountpoint)) {
+        if (!shell->runAsRoot("mount " + part + ' ' + path + mountpoint)) {
             QMessageBox::critical(this, tr("Error"), tr("Sorry, could not mount %1 partition").arg(mountpoint));
             return false;
         }
